@@ -11,6 +11,8 @@ import json
 from kivy.app import App
 from kivy.uix.widget import Widget
 from kivy.graphics import Color, Ellipse, Line
+from kivy.logger import Logger
+Logger.setLevel(logging.ERROR)
 # mine
 import hwrt.utils as utils
 
